==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/HVCore/src/HVTaskManager.cpp <==
/***************************************************************************
**
**  This file is part of HVCore.
**
**  HVCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  HVCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-02-18
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "HVTaskManager.h"
#include "HVTask.h"
#include "HVWorker.h"
#include "AbstractStation.h"

namespace HVCore {

  /*!
    \class HVTaskManager HVTaskManager.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  /*!
    Description of constructor still missing
  */
  HVTaskManager::HVTaskManager(const QList<AbstractStation *>& stations)
    : TaskManager()
  {
    TRACE;
    _stations=stations;
  }

  /*!
    Description of destructor still missing
  */
  HVTaskManager::~HVTaskManager()
  {
    TRACE;
  }

  bool HVTaskManager::setParameters(const HVParameters * param)
  {
    TRACE;
    _parameters=param;
    return true;
  }

  LoopWorker * HVTaskManager::newWorker()
  {
    TRACE;
    HVWorker * w=new HVWorker;
    w->setTaskManager(this);
    return w;
  }

  AbstractTask * HVTaskManager::createTask(int taskIndex)
  {
    TRACE;
    return new HVTask(this, taskIndex, _stations.at(taskIndex));
  }

  void HVTaskManager::setTasks()
  {
    TRACE;
    TaskManager::setTasks(_stations.count());
  }

} // namespace HVCore

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/HVCore/src/HVTaskManager.cpp <==
/***************************************************************************
**
**  This file is part of HVCore.
**
**  HVCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  HVCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-02-18
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "HVTaskManager.h"
#include "HVTask.h"
#include "HVWorker.h"
#include "AbstractStation.h"

namespace HVCore {

  /*!
    \class HVTaskManager HVTaskManager.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  /*!
    Description of constructor still missing
  */
  HVTaskManager::HVTaskManager(const QList<AbstractStation *>& stations)
    : ParallelTaskManager()
  {
    TRACE;
    _stations=stations;
  }

  /*!
    Description of destructor still missing
  */
  HVTaskManager::~HVTaskManager()
  {
    TRACE;
  }

  bool HVTaskManager::setParameters(const HVParameters * param)
  {
    TRACE;
    _parameters=param;
    return true;
  }

  LoopWorker * HVTaskManager::newWorker()
  {
    TRACE;
    HVWorker * w=new HVWorker;
    w->setTaskManager(this);
    return w;
  }

  ParallelTask * HVTaskManager::createTask(int taskIndex)
  {
    TRACE;
    return new HVTask(this, taskIndex, _stations.at(taskIndex));
  }

  void HVTaskManager::setTasks()
  {
    TRACE;
    ParallelTaskManager::setTasks(_stations.count());
  }

} // namespace HVCore
